@@ -39,7 +39,6 @@
 
 /* The image has been mirrored (so starter should be, too) */
 /* (as of API version 0x00000001) */
-
 #define SPECIAL_MIRROR	0x0001
 
 /* The image has been flipped (so starter should be, too) */
@@ -47,6 +46,12 @@
 #define SPECIAL_FLIP	0x0002
 
 
+/* Flags you return when asked what modes you work in */
+/* (as of API version 0x00000002) */
+#define MODE_PAINT      0x0001  /* User can paint the tool, freehand */
+#define MODE_FULLSCREEN 0x0002  /* User can apply effect to entire canvas at once */
+#define MAX_MODES 2
+
 typedef struct magic_api_t {
   /* A string containing the current version of Tux Paint (e.g., "0.9.18") */
   char * tp_version;
@@ -135,7 +140,7 @@ typedef struct magic_api_t {
    If Tux Paint deems you compatible, it will call your 'XYZ_init()' (etc.)
    and you will be active. */
 
-#define TP_MAGIC_API_VERSION 0x00000001
+#define TP_MAGIC_API_VERSION 0x00000002
 
 #ifndef ATTRIBUTE_UNUSED
 #define ATTRIBUTE_UNUSED __attribute__ ((__unused__))
